@@ -36,7 +36,7 @@ from socket import SOCK_DGRAM
 from socket import SOCK_STREAM
 
 import psutil
-from psutil import OSX
+from psutil import MACOS
 from psutil import POSIX
 from psutil import SUNOS
 from psutil import WINDOWS
@@ -125,7 +125,7 @@ NO_RETRIES = 10
 # bytes tolerance for system-wide memory related tests
 MEMORY_TOLERANCE = 500 * 1024  # 500KB
 # the timeout used in functions which have to wait
-GLOBAL_TIMEOUT = 3
+GLOBAL_TIMEOUT = 3 if TRAVIS or APPVEYOR else 0.5
 # test output verbosity
 VERBOSITY = 1 if os.getenv('SILENT') or TOX else 2
 # be more tolerant if we're on travis / appveyor in order to avoid
@@ -137,7 +137,16 @@ if TRAVIS or APPVEYOR:
 # --- files
 
 TESTFILE_PREFIX = '$testfn'
+if os.name == 'java':
+    # Jython disallows @ in module names
+    TESTFILE_PREFIX = '$psutil-test-'
+else:
+    TESTFILE_PREFIX = '@psutil-test-'
 TESTFN = os.path.join(os.path.realpath(os.getcwd()), TESTFILE_PREFIX)
+# Disambiguate TESTFN for parallel testing, while letting it remain a valid
+# module name.
+TESTFN = TESTFN + str(os.getpid())
+
 _TESTFN = TESTFN + '-internal'
 TESTFN_UNICODE = TESTFN + u("-ƒőő")
 ASCII_FS = sys.getfilesystemencoding().lower() in ('ascii', 'us-ascii')
@@ -179,7 +188,7 @@ def _get_py_exe():
         else:
             return exe
 
-    if OSX:
+    if MACOS:
         exe = \
             attempt(sys.executable) or \
             attempt(os.path.realpath(sys.executable)) or \
@@ -206,8 +215,13 @@ _pids_started = set()
 _testfiles_created = set()
 
 
+def logstderr(s):
+    print(s, file=sys.stderr)
+
+
 @atexit.register
-def _cleanup_files():
+def cleanup_test_files():
+    logstderr("executing cleanup_test_files() atexit function")
     DEVNULL.close()
     for name in os.listdir(u('.')):
         if isinstance(name, unicode):
@@ -215,11 +229,13 @@ def _cleanup_files():
         else:
             prefix = TESTFILE_PREFIX
         if name.startswith(prefix):
+            logstderr("removing temporary test file %r" % name)
             try:
                 safe_rmpath(name)
             except Exception:
                 traceback.print_exc()
     for path in _testfiles_created:
+        logstderr("removing temporary test file %r" % path)
         try:
             safe_rmpath(path)
         except Exception:
@@ -228,7 +244,8 @@ def _cleanup_files():
 
 # this is executed first
 @atexit.register
-def _cleanup_procs():
+def cleanup_test_procs():
+    logstderr("executing cleanup_test_procs() atexit function")
     reap_children(recursive=True)
 
 
@@ -367,7 +384,7 @@ def create_proc_children_pair():
 def create_zombie_proc():
     """Create a zombie process and return its PID."""
     assert psutil.POSIX
-    unix_file = tempfile.mktemp(prefix=TESTFILE_PREFIX) if OSX else TESTFN
+    unix_file = tempfile.mktemp(prefix=TESTFILE_PREFIX) if MACOS else TESTFN
     src = textwrap.dedent("""\
         import os, sys, time, socket, contextlib
         child_pid = os.fork()
